@@ -1,4 +1,4 @@
-/* $Id: libgadu.h 437088 2005-07-20 22:20:52Z mueller $ */
+/* $Id: libgadu.h 523660 2006-03-28 19:17:53Z gj $ */
 
 /*
  *  (C) Copyright 2001-2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -33,10 +33,6 @@
 extern "C" {
 #endif
 
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#endif
-	
 #include <libgadu-config.h>
 #include <sys/types.h>
 #include <stdio.h>
@@ -441,7 +437,9 @@ enum gg_failure_t {
 	GG_FAILURE_PASSWORD,		/* nieprawidowe haso */
 	GG_FAILURE_404, 		/* XXX nieuywane */
 	GG_FAILURE_TLS,			/* bd negocjacji TLS */
-	GG_FAILURE_NEED_EMAIL 		/* serwer rozczy nas z prob o zmian emaila */
+	GG_FAILURE_NEED_EMAIL, 		/* serwer rozczy nas z prob o zmian emaila */
+	GG_FAILURE_INTRUDER,		/* za duo prb poczenia si z nieprawidowym hasem */
+	GG_FAILURE_UNAVAILABLE		/* serwery s wyczone */
 };
 
 /*
