@@ -27,7 +27,9 @@ class dlgJabberVCard;
 class JabberProtocol;
 class JabberAccount;
 class JabberResource;
+class JabberTransport;
 namespace Kopete { class MetaContact; }
+namespace XMPP { class VCard; }
 
 class JabberBaseContact : public Kopete::Contact
 {
@@ -37,8 +39,12 @@ friend class JabberAccount;	/* Friends can touch each other's private parts. */
 
 public:
 
+	/**
+	 * @param legacyId is the contactId of the contact if != Jid
+	 */
 	JabberBaseContact (const XMPP::RosterItem &rosterItem,
-				   JabberAccount *account, Kopete::MetaContact * mc);
+					   Kopete::Account *account, Kopete::MetaContact * mc, 
+					   const QString &legacyId=QString());
 
 	/********************************************************************
 	 *
@@ -54,8 +60,13 @@ public:
 	/**
 	 * Return the account instance associated with this contact
 	 */
-	JabberAccount *account ();
-
+	JabberAccount *account () const { return m_account; };
+	
+	/**
+	 * return the transport if any, or null
+	 */
+	JabberTransport *transport();
+			
 	/**
 	 * Return if the contact is reachable (this is true if the account
 	 * is online)
@@ -73,11 +84,6 @@ public:
 	 */
 	virtual void serialize (QMap < QString, QString > &serializedData, QMap < QString, QString > &addressBookData);
 
-	/**
-	 * Start a rename request.
-	 */
-	virtual void rename ( const QString &newName ) = 0;
-
 	/**
 	 * Update contact if a roster item has been
 	 * received for it. (used during login)
@@ -90,11 +96,10 @@ public:
 	virtual void handleIncomingMessage ( const XMPP::Message &message ) = 0;
 
 	/**
-	 * Re-evaluate online status. Gets called
-	 * whenever a resource is added, removed, or
-	 * changed in the resource pool.
+	 * Update the resource property of the
+	 * contact, listing all available resources.
 	 */
-	void reevaluateStatus ();
+	void updateResourceList ();
 
 	/**
 	 * Return current full address.
@@ -103,12 +108,56 @@ public:
 	 */
 	QString fullAddress ();
 
+	/**
+	 * Set the dontSync flag for this contact.
+	 * If this flag is set, calls to @ref sync will
+	 * be ignored. This is required if the contact
+	 * has been moved between groups on the server
+	 * after we logged in and we try to update our
+	 * local contact list. Since libkopete can only
+	 * handle one group update at a time, moving
+	 * between groups requires to operations which
+	 * each in turn would cause a call to sync(),
+	 * overwriting the change that is being carried
+	 * out. (besides causing unnecessary traffic)
+	 * This is avoided by setting the dontSync flag
+	 * while synchronizing the local copy.
+	 */
+	void setDontSync ( bool flag );
+
+	/**
+	 * Return the status of the dontSync flag.
+	 * See @ref setDontSync for a full description.
+	 */
+	bool dontSync ();
+	
+	/**
+	 * return the roster item of the contact.
+	 * to get the jid, use  rosterItem().jid().full()  don't use contactId as it is not the same with transport
+	 */
+	XMPP::RosterItem rosterItem() const { return mRosterItem; }
+	
+	/**
+	 * Reads a vCard object and updates the contact's
+	 * properties accordingly.
+	 */
+	void setPropertiesFromVCard ( const XMPP::VCard &vCard );
+
+
 public slots:
 
 	/**
 	 * Retrieve a vCard for the contact
 	 */
-	virtual void slotUserInfo () = 0;
+	virtual void slotUserInfo ();
+	
+	
+	/**
+	 * Re-evaluate online status. Gets called
+	 * whenever a resource is added, removed, or
+	 * changed in the resource pool.
+	 */
+	void reevaluateStatus ();
 
 protected:
 	/**
@@ -125,6 +174,10 @@ protected:
 	 */
 	XMPP::RosterItem mRosterItem;
 
+private:
+	bool mDontSync;
+	JabberAccount *m_account;
+
 };
 
 #endif
