@@ -196,8 +196,7 @@ void MSNSocket::slotSocketError( int error )
 	//like if the socket is closed
 	emit socketClosed();
 
-	//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error, errormsg, i18n( "MSN Plugin" ) );
-	emit errorMessage( ErrorNormal, errormsg );
+	emit errorMessage( ErrorConnectionError, errormsg );
 }
 
 void MSNSocket::slotDataReceived()
@@ -293,14 +292,15 @@ void MSNSocket::slotDataReceived()
 
 				// At this point, we have all the bytes returned from the web request.
 				bytes = m_buffer.take(m_buffer.size());
-				delete[] buffer;
 			}
-
-			if(bytes.size() == 0) {
+			
+			if(bytes.size() == 0) 
+			{
 				// The response headers and the content came in one packet.
 				bytes.assign(buffer, avail);
 			}
 
+
 			// Create the web response object from the response bytes.
 			WebResponse response(bytes);
 
@@ -530,7 +530,7 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 {
 	kdDebug(14140) << k_funcinfo << endl;
 	QString msg;
-
+	ErrorType type = ErrorServerError;
 	switch ( code )
 	{
 /*
@@ -566,15 +566,19 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 */
 	case 500:
 		msg = i18n ( "An internal server error occurred. Please try again later." );
+		type = MSNSocket::ErrorCannotConnect;
 		break;
 	case 502:
 		msg = i18n ( "It is no longer possible to perform this operation. The MSN server does not allow it anymore." );
+		type = MSNSocket::ErrorServerError;
 		break;
 	case 600:
 	case 910:
 	case 912:
+	case 921:
 	case 922:
 		msg = i18n ( "The MSN server is busy. Please try again later." );
+		type = MSNSocket::ErrorConnectionError;
 		break;
 	case 601:
 	case 604:
@@ -584,7 +588,9 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 	case 916:
 	case 917:
 		msg = i18n ( "The server is not available at the moment. Please try again later." );
+		type = MSNSocket::ErrorCannotConnect;
 		break;
+	// Server error
 	default:
 		// FIXME: if the error causes a disconnect, it will crash, but we can't disconnect every time
 		msg = i18n( "Unhandled MSN error code %1 \n"
@@ -594,8 +600,7 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 	}
 
 	if ( !msg.isEmpty() )
-		//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error, msg, i18n( "MSN Plugin" ) );
-		emit errorMessage( ErrorNormal, msg );
+		emit errorMessage( type, msg );
 
 	return;
 }
@@ -772,12 +777,19 @@ QString MSNSocket::escape( const QString &str )
 	QString result = QString(new_segment, new_length);
 	delete [] new_segment;
 	return result;
+
 }
 
 QString MSNSocket::unescape( const QString &str )
 {
-	//GRRRRR F*CKING MSN PLUS USERS! They insert these stupid color codes in their nickname, and messages are not correctly shown
-	return KURL::decode_string( str, 106 ).replace( QRegExp("[\\x1-\\x8]"), "" );
+	QString str2 = KURL::decode_string( str, 106 );
+	//remove msn+ colors code
+	str2 = str2.replace( QRegExp("[\\x1-\\x8]"), "" ); // old msn+ colors
+	// added by kaoul <erwin.kwolek at gmail.com>
+	str2 = str2.replace( QRegExp("\\xB7[&@\'#0]"),""); // dot ...
+	str2 = str2.replace( QRegExp("\\xB7\\$,?\\d{1,2}"),""); // dot dollar (comma)? 0-99
+
+	return str2;
 }
 
 void MSNSocket::slotConnectionSuccess()
