@@ -20,6 +20,7 @@
 #define OFFLINEMESSAGESTASK_H
 
 #include "icqtask.h"
+#include "oscarmessage.h"
 
 /**
 ICQ Offline messages handling
@@ -47,7 +48,6 @@ private:
 	void deleteOfflineMessages();
 	
 private:
-	int m_msgCount;
 	int m_sequence;
 };
 
