@@ -36,13 +36,15 @@ class MainConfig : public MainConfigBase
     void load();
     void save();
 
+    void registerConfig( int number );
+    void unregisterConfig( int number );
+
   signals:
     void changed();
     void activateClicked();
 
   protected slots:
-    void slotAutoDetect();
-    void slotTestInterface( KProcIO *proc );
+    void slotChangeNumConfigs( int newnumber );
 };
 
 #endif // CONFIGMAIN_H
